use Renard::Curie::Setup;
package Renard::Curie::Model::Document;
# ABSTRACT: Base class for representing documents
$Renard::Curie::Model::Document::VERSION = '0.001';
use Moo;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Renard::Curie::Model::Document - Base class for representing documents

=head1 VERSION

version 0.001

=head1 EXTENDS

=over 4

=item * L<Moo::Object>

=back

=head1 AUTHOR

Project Renard

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Project Renard.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
